@@ -6,5 +6,5 @@ use Net::Libdnet::Intf;
 my $intf = shift || die("Pass interface");
 
 my $h = Net::Libdnet::Intf->new;
-my $info = $h->get($intf);
+my $info = $h->get($intf) or die("FATAL: get");
 print $info->print."\n";
